@@ -852,15 +852,16 @@ void MainWindow::loadMainWindowSettings()
     if (settings.isShowPrivacyPopup()) {
         const QString href = QStringLiteral("<a href=\"%1\">%2</a>");
         const QString mozhiLink = href.arg(QStringLiteral("https://codeberg.org/aryak/mozhi"), QStringLiteral("Mozhi"));
-        const QString instanceLink = href.arg(settings.instanceUrl(), settings.instanceUrl());
+        const QString instanceLink = href.arg(settings.instance(), settings.instance());
         QMessageBox messageBox;
-        messageBox.setIcon(QMessageBox::Warning);
+        messageBox.setIcon(QMessageBox::Information);
         messageBox.setWindowTitle(APPLICATION_NAME);
         messageBox.setText(tr("This application uses %1 to provide translations.").arg(mozhiLink));
         messageBox.setInformativeText(tr("While Mozhi acts as a proxy to protect your privacy,"
                                          " the third-party services it uses may store and analyze"
-                                         " the text you send. We randomly assigned you instance %1,"
-                                         " but you can change it in the translation settings.")
+                                         " the text you send. Your instance right now is '%1',"
+                                         " but you can change it in the translation settings."
+                                         " See instance details in the link above.")
                                           .arg(instanceLink));
 
         QCheckBox dontShowAgainCheckBox(tr("Don't show again"));
@@ -914,7 +915,7 @@ void MainWindow::loadAppSettings()
     m_forceTranslationAutodetect = settings.isForceTranslationAutodetect();
 
     // Instance settings
-    m_translator->setInstanceUrl(settings.instanceUrl());
+    m_translator->setInstance(settings.instance());
 
     // OCR settings
     if (const QByteArray languages = settings.ocrLanguagesString(), path = settings.ocrLanguagesPath(); !m_ocr->init(languages, path, settings.tesseractParameters())) {
