@@ -72,7 +72,7 @@ void AppSettings::applyLocale(const QLocale &locale)
     if (s_qtTranslator.load(newLocale, QStringLiteral("qt"), QStringLiteral("_"), QLibraryInfo::location(QLibraryInfo::TranslationsPath))) {
         QCoreApplication::installTranslator(&s_qtTranslator);
     } else {
-        QCoreApplication::removeTranslator(&s_appTranslator);
+        QCoreApplication::removeTranslator(&s_qtTranslator);
     }
 }
 
@@ -506,39 +506,14 @@ bool AppSettings::defaultForceTranslationAutodetect()
     return true;
 }
 
-QString AppSettings::instanceUrl() const
+QString AppSettings::instance() const
 {
-    return m_settings->value(QStringLiteral("Translation/InstanceUrl"), randomInstanceUrl()).toString();
+    return m_settings->value(QStringLiteral("Translation/Instance")).toString();
 }
 
-void AppSettings::setInstanceUrl(const QString &url)
+void AppSettings::setInstance(const QString &url)
 {
-    m_settings->setValue(QStringLiteral("Translation/InstanceUrl"), url);
-}
-
-QString AppSettings::randomInstanceUrl()
-{
-    // Pick random instance by default to spread load
-    QStringList urls = AppSettings::instanceUrls();
-    int randomNumber = QRandomGenerator::global()->bounded(urls.size());
-    return urls[randomNumber];
-}
-
-QStringList AppSettings::instanceUrls()
-{
-    return {
-        QStringLiteral("https://mozhi.aryak.me"),
-        QStringLiteral("https://translate.bus-hit.me"),
-        QStringLiteral("https://nyc1.mz.ggtyler.dev"),
-        QStringLiteral("https://translate.projectsegfau.lt"),
-        QStringLiteral("https://translate.nerdvpn.de"),
-        QStringLiteral("https://mozhi.ducks.party"),
-        QStringLiteral("https://mozhi.frontendfriendly.xyz"),
-        QStringLiteral("https://mozhi.pussthecat.org"),
-        QStringLiteral("https://mo.zorby.top"),
-        QStringLiteral("https://mozhi.adminforge.de"),
-        QStringLiteral("https://translate.privacyredirect.com"),
-    };
+    m_settings->setValue(QStringLiteral("Translation/Instance"), url);
 }
 
 QNetworkProxy::ProxyType AppSettings::proxyType() const
