@@ -8,6 +8,8 @@
 #include "settingsdialog.h"
 #include "ui_settingsdialog.h"
 
+#include "instancepinger.h"
+#include "instancepingerdialog.h"
 #include "mainwindow.h"
 #include "qhotkey.h"
 #include "screenwatcher.h"
@@ -62,7 +64,7 @@ SettingsDialog::SettingsDialog(MainWindow *parent)
     ui->ocrLanguagesListWidget->addLanguages(parent->ocr()->availableLanguages());
 
     // Set all avaialble instances
-    ui->mozhiUrlComboBox->addItems(AppSettings::instanceUrls());
+    ui->mozhiUrlComboBox->addItems(InstancePinger::instances());
 
     // Sort languages in comboboxes alphabetically
     ui->primaryLangComboBox->model()->sort(0);
@@ -163,7 +165,7 @@ void SettingsDialog::accept()
     settings.setForceTranslationAutodetect(ui->forceTranslationAutodetectCheckBox->isChecked());
 
     // Instance settings
-    settings.setInstanceUrl(ui->mozhiUrlComboBox->currentText());
+    settings.setInstance(ui->mozhiUrlComboBox->currentText());
 
     // OCR
     settings.setConvertLineBreaks(ui->convertLineBreaksCheckBox->isChecked());
@@ -258,6 +260,23 @@ void SettingsDialog::setCustomTrayIconPreview(const QString &iconPath)
     ui->customTrayIconButton->setIcon(TrayIcon::customTrayIcon(iconPath));
 }
 
+void SettingsDialog::detectFastestInstance()
+{
+    ui->detectFastestButton->setEnabled(false);
+
+    auto *dialog = new InstancePingerDialog(this);
+    connect(dialog, &InstancePingerDialog::canceled, dialog, [this, dialog]() {
+        ui->detectFastestButton->setEnabled(true);
+        dialog->deleteLater();
+    });
+    connect(dialog, &InstancePingerDialog::accepted, [this, dialog]() {
+        ui->mozhiUrlComboBox->setCurrentText(dialog->fastestUrl());
+        ui->detectFastestButton->setEnabled(true);
+        dialog->deleteLater();
+    });
+    dialog->show();
+}
+
 void SettingsDialog::selectOcrLanguagesPath()
 {
     const QString path = ui->ocrLanguagesPathEdit->text().left(ui->ocrLanguagesPathEdit->text().lastIndexOf(QDir::separator()));
@@ -362,8 +381,7 @@ void SettingsDialog::restoreDefaults()
     ui->forceSourceAutodetectCheckBox->setChecked(AppSettings::defaultForceSourceAutodetect());
     ui->forceTranslationAutodetectCheckBox->setChecked(AppSettings::defaultForceTranslationAutodetect());
 
-    // Instance settings
-    ui->mozhiUrlComboBox->setCurrentText(AppSettings::randomInstanceUrl());
+    // We don't reset the picked instance
 
     // OCR
     ui->convertLineBreaksCheckBox->setChecked(AppSettings::defaultConvertLineBreaks());
@@ -462,7 +480,7 @@ void SettingsDialog::loadSettings()
     ui->forceTranslationAutodetectCheckBox->setChecked(settings.isForceTranslationAutodetect());
 
     // Instance settings
-    ui->mozhiUrlComboBox->setCurrentText(settings.instanceUrl());
+    ui->mozhiUrlComboBox->setCurrentText(settings.instance());
 
     // OCR
     ui->convertLineBreaksCheckBox->setChecked(settings.isConvertLineBreaks());
